import { isUndefined } from '@freik/typechk';
// Get the menu "parent" from the parsed file
// This is a map of "ID" to the actual title of the user menu
function getMenus(parsedFile) {
    const menuSym = parsedFile.scopedTable.get('menu');
    if (isUndefined(menuSym)) {
        return new Map();
    }
    return new Map([...menuSym.children].map(([id, sym]) => [id, sym.name]));
}
// Create an individual board from the symbols we've got.
function makeBoard(val, menus) {
    const menuSyms = val.children.get('menu')?.children || new Map();
    // Validate that the menu selections are available in the menu options enumerated
    const menuSelections = [];
    menuSyms.forEach((ss, key) => {
        if (!menus.has(key)) {
            // TODO: Throw an error here? Make a 'warning' level?
            console.error(`Boards.txt file looks malformed: Missing ${key} from the menu list`);
        }
        else {
            menuSelections.push(ss);
        }
    });
    return { menuSelections, symbols: val };
}
// Create a board for each board in the parsed file
export function EnumerateBoards(board) {
    const menus = getMenus(board);
    const boards = new Map();
    board.scopedTable.forEach((val, key) => {
        if (key !== 'menu') {
            const boardId = key;
            boards.set(boardId, makeBoard(val, menus));
        }
    });
    return { menus, boards };
}
