import { SafelyUnpickle, chkArrayOf, chkObjectOfType, hasFieldType, isArray, isString, isUndefined, } from '@freik/typechk';
import { promises as fs } from 'fs';
import { Dump } from './dump.js';
const isTransformItem = chkObjectOfType({
    defmatch: isString,
    text: isString,
    replace: isString,
});
const isFilterItem = chkObjectOfType({
    defmatch: isString,
    remove: isString,
});
function isConfig(i) {
    return (hasFieldType(i, 'transforms', chkArrayOf(isTransformItem)) ||
        hasFieldType(i, 'filters', chkArrayOf(isFilterItem)));
}
let config;
export async function LoadConfig(cfgPath) {
    try {
        const cfg = await fs.readFile(cfgPath, 'utf-8');
        config = SafelyUnpickle(cfg, isConfig);
        if (isUndefined(config)) {
            Dump('err')('Invalid config file:');
            Dump('err')(config);
        }
    }
    catch (e) {
        Dump('err')('Unable to read config file:');
        Dump('err')(e);
    }
}
export function AddConfig(cfg) {
    if (isUndefined(config)) {
        config = cfg;
    }
    else {
        config = { ...config, ...cfg };
    }
}
export function Transform(name, value) {
    if (!config || !isArray(config.transforms)) {
        return { name, value };
    }
    for (const { defmatch, text, replace } of config.transforms) {
        // For now just do a simple "indexOf" for matching, I guess
        if (name.indexOf(defmatch) >= 0) {
            value = value.replace(text, replace);
        }
    }
    return { name, value };
}
export function Filter(name, files) {
    if (!config || !isArray(config.filters)) {
        return files;
    }
    for (const { defmatch, remove } of config.filters) {
        if (name === defmatch) {
            files = files.filter((val) => val.indexOf(remove) < 0);
        }
    }
    return files;
}
