import { GetPlainValue } from '../utils.js';
import { MakeDeclDef, MakeDefinitions, MakeIfeq } from './gmUtils.js';
function makeMenuOption(toDump, initConds) {
    const defined = [];
    const makeVarName = 'IN_' + toDump.name.toUpperCase();
    for (const item of toDump.children.values()) {
        const cn = MakeIfeq('${' + makeVarName + '}', item.name);
        const subDef = MakeDefinitions(item, GetPlainValue, [...initConds, cn]);
        subDef.forEach((def) => {
            def.dependsOn.push(makeVarName);
        });
        defined.push(...subDef);
    }
    return defined;
}
const notMenu = (a) => a.name !== 'menu';
// This spits out the board configuration data in Makefile format
// It returns the set of *probably* defined variables, for use later
// TODO: Hoist common IF's for the menu options (Go look at Teensy...)
export function GenBoardDefs(board) {
    const defined = [
        MakeDeclDef('BUILD_PROJECT_NAME', '${PROJ_NAME}', ['PROJ_NAME'], []),
    ];
    board.boards.forEach(({ symbols, menuSelections }, key) => {
        // Handle each board-specific definition
        const brd = MakeIfeq('${BOARD_NAME}', key);
        const defVars = MakeDefinitions(symbols, GetPlainValue, [brd], notMenu);
        defVars.forEach((def) => def.dependsOn.push('BOARD_NAME'));
        defined.push(...defVars);
        // Now handle the menu selections for the board
        menuSelections
            .map((ss) => makeMenuOption(ss, [brd]))
            .forEach((defs) => defined.push(...defs));
    });
    return defined;
}
