import { isUndefined } from '@freik/typechk';
import { Filter } from '../config.js';
// Utilities for doing Makefile stuff
// ifeq (VAR, value)
export function MakeIfeq(variable, value) {
    return {
        op: 'eq',
        variable,
        value,
    };
}
// ifneq (VAR, value)
export function MakeIfneq(variable, value) {
    return {
        op: 'neq',
        variable,
        value,
    };
}
// ifdef VAR
export function MakeIfdef(variable) {
    return {
        op: 'def',
        variable,
    };
}
// ifndef VAR
export function MakeIfndef(variable) {
    return {
        op: 'ndef',
        variable,
    };
}
// if variable
export function MakeIf(variable) {
    return { op: 'raw', variable };
}
export function MakeSeqDef(name, value, dependsOn, condition) {
    return {
        name,
        type: 'seq',
        value,
        dependsOn: dependsOn || [],
        condition: condition || [],
    };
}
export function MakeAppend(name, value, dependsOn, condition) {
    return {
        name,
        type: 'add',
        value,
        dependsOn: dependsOn || [],
        condition: condition || [],
    };
}
export function MakeUnDecl(name, value, dependsOn, condition) {
    return {
        name,
        type: '?decl',
        value,
        dependsOn: dependsOn || [],
        condition: condition || [],
    };
}
export function MakifyName(nm) {
    return nm.toUpperCase().replace(/[^A-Z0-9]/g, '_');
}
// Upper-cases with underscores
function getMakeName(vrbl, top) {
    let name = vrbl.name;
    while (vrbl.parent && vrbl.parent !== top) {
        vrbl = vrbl.parent;
        name = vrbl.name + '_' + name;
    }
    return MakifyName(name);
}
export function MakeDefinitions(top, valueMaker, condition, filter) {
    const defined = [];
    const toDef = [...top.children.values()];
    while (toDef.length > 0) {
        const foo = toDef.pop();
        if (!foo)
            continue; // Typescript is dumber than Flow here...
        const vrbl = foo;
        if (!filter || filter(vrbl)) {
            toDef.push(...vrbl.children.values());
            if (vrbl.value) {
                const varName = getMakeName(vrbl, top);
                const { value, unresolved: deps } = valueMaker(vrbl);
                const def = MakeDeclDef(varName, value, [...deps], condition || []);
                defined.push(def);
            }
        }
    }
    return defined;
}
export function MakeDeclDef(name, value, dependsOn, condition) {
    return {
        name,
        type: 'decl',
        value,
        dependsOn: dependsOn || [],
        condition: condition || [],
    };
}
export function prefixAndJoinFiles(filteredFiles, prefixer, trimmer) {
    if (!isUndefined(prefixer)) {
        if (isUndefined(trimmer)) {
            filteredFiles = filteredFiles.map(prefixer);
        }
        else {
            const reAdd = new Set();
            filteredFiles = filteredFiles
                .map((val, index) => {
                if (val.startsWith(trimmer)) {
                    reAdd.add(index);
                    return val.substring(trimmer.length);
                }
                return val;
            })
                .map(prefixer)
                .map((val, index) => (reAdd.has(index) ? trimmer + val : val));
        }
    }
    return filteredFiles.join(' \\\n    ');
}
export function MakeSrcList(name, files, depend, cnd, prefixer, trimmer) {
    // Filter out user-specified files to remove...
    const filteredFiles = Filter(name, files);
    return MakeAppend(name, prefixAndJoinFiles(filteredFiles, prefixer, trimmer), typeof depend === 'string' ? [depend] : depend, cnd);
}
